import { alert } from 'vscode/vscode/vs/base/browser/ui/aria/aria';
import { localize } from 'vscode/vscode/vs/nls';
import { Disposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { toErrorMessage } from 'vscode/vscode/vs/base/common/errorMessage';
import { NotificationPriority } from 'vscode/vscode/vs/platform/notification/common/notification';
import { Event } from 'vscode/vscode/vs/base/common/event';
import Severity$1 from 'vscode/vscode/vs/base/common/severity';

class NotificationsAlerts extends Disposable {
    constructor(model) {
        super();
        this.model = model;
        for (const notification of model.notifications) {
            this.triggerAriaAlert(notification);
        }
        this.registerListeners();
    }
    registerListeners() {
        this._register(this.model.onDidChangeNotification(e => this.onDidChangeNotification(e)));
    }
    onDidChangeNotification(e) {
        if (e.kind === 0 ) {
            this.triggerAriaAlert(e.item);
            if (e.item.severity === Severity$1.Error) {
                if (e.item.message.original instanceof Error) {
                    console.error(e.item.message.original);
                }
                else {
                    console.error(toErrorMessage(( (e.item.message.linkedText.toString())), true));
                }
            }
        }
    }
    triggerAriaAlert(notification) {
        if (notification.priority === NotificationPriority.SILENT) {
            return;
        }
        const listener = notification.onDidChangeContent(e => {
            if (e.kind === 1 ) {
                this.doTriggerAriaAlert(notification);
            }
        });
        Event.once(notification.onDidClose)(() => listener.dispose());
        this.doTriggerAriaAlert(notification);
    }
    doTriggerAriaAlert(notification) {
        let alertText;
        if (notification.severity === Severity$1.Error) {
            alertText = ( localize(
                2643,
                "Error: {0}",
                 (notification.message.linkedText.toString())
            ));
        }
        else if (notification.severity === Severity$1.Warning) {
            alertText = ( localize(
                2644,
                "Warning: {0}",
                 (notification.message.linkedText.toString())
            ));
        }
        else {
            alertText = ( localize(
                2645,
                "Info: {0}",
                 (notification.message.linkedText.toString())
            ));
        }
        alert(alertText);
    }
}

export { NotificationsAlerts };
